@@ -58,7 +58,7 @@ void PlacesItem::setUrl(const QUrl &url)
     // like QUrl. Hence do a manual check to prevent that
     // setting an equal URL results in an itemsChanged()
     // signal.
-    if (dataValue("url").value<QUrl>() != url) {
+    if (dataValue("url").toUrl() != url) {
         delete m_trashDirLister;
         if (url.scheme() == QLatin1String("trash")) {
             // The trash icon must always be updated dependent on whether
@@ -79,7 +79,7 @@ void PlacesItem::setUrl(const QUrl &url)
 
 QUrl PlacesItem::url() const
 {
-    return dataValue("url").value<QUrl>();
+    return dataValue("url").toUrl();
 }
 
 void PlacesItem::setUdi(const QString& udi)
@@ -131,7 +131,7 @@ void PlacesItem::setBookmark(const KBookmark& bookmark)
     delete m_mtp;
 
 
-    const QString udi = bookmark.metaDataItem("UDI");
+    const QString udi = bookmark.metaDataItem(QStringLiteral("UDI"));
     if (udi.isEmpty()) {
         setIcon(bookmark.icon());
         setText(i18nc("KFile System Bookmarks", bookmark.text().toUtf8().constData()));
@@ -143,10 +143,10 @@ void PlacesItem::setBookmark(const KBookmark& bookmark)
     const GroupType type = groupType();
     if (icon().isEmpty()) {
         switch (type) {
-        case RecentlySavedType: setIcon("chronometer"); break;
-        case SearchForType:     setIcon("system-search"); break;
+        case RecentlySavedType: setIcon(QStringLiteral("chronometer")); break;
+        case SearchForType:     setIcon(QStringLiteral("system-search")); break;
         case PlacesType:
-        default:                setIcon("folder");
+        default:                setIcon(QStringLiteral("folder"));
         }
 
     }
@@ -159,7 +159,7 @@ void PlacesItem::setBookmark(const KBookmark& bookmark)
     default:                Q_ASSERT(false); break;
     }
 
-    setHidden(bookmark.metaDataItem("IsHidden") == QLatin1String("true"));
+    setHidden(bookmark.metaDataItem(QStringLiteral("IsHidden")) == QLatin1String("true"));
 }
 
 KBookmark PlacesItem::bookmark() const
@@ -206,7 +206,7 @@ KBookmark PlacesItem::createBookmark(KBookmarkManager* manager,
 
     KBookmark bookmark = root.addBookmark(text, url, iconName);
     bookmark.setFullText(text);
-    bookmark.setMetaDataItem("ID", generateNewId());
+    bookmark.setMetaDataItem(QStringLiteral("ID"), generateNewId());
 
     return bookmark;
 }
@@ -220,8 +220,8 @@ KBookmark PlacesItem::createDeviceBookmark(KBookmarkManager* manager,
     }
 
     KBookmark bookmark = root.createNewSeparator();
-    bookmark.setMetaDataItem("UDI", udi);
-    bookmark.setMetaDataItem("isSystemItem", "true");
+    bookmark.setMetaDataItem(QStringLiteral("UDI"), udi);
+    bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
     return bookmark;
 }
 
@@ -270,8 +270,8 @@ void PlacesItem::initializeDevice(const QString& udi)
 
     if (m_access) {
         setUrl(QUrl::fromLocalFile(m_access->filePath()));
-        QObject::connect(m_access.data(), SIGNAL(accessibilityChanged(bool,QString)),
-                         m_signalHandler.data(), SLOT(onAccessibilityChanged()));
+        QObject::connect(m_access.data(), &Solid::StorageAccess::accessibilityChanged,
+                         m_signalHandler.data(), &PlacesItemSignalHandler::onAccessibilityChanged);
     } else if (m_disc && (m_disc->availableContent() & Solid::OpticalDisc::Audio) != 0) {
         Solid::Block *block = m_device.as<Solid::Block>();
         if (block) {
@@ -296,7 +296,7 @@ void PlacesItem::onTrashDirListerCompleted()
     Q_ASSERT(url().scheme() == QLatin1String("trash"));
 
     const bool isTrashEmpty = m_trashDirLister->items().isEmpty();
-    setIcon(isTrashEmpty ? "user-trash" : "user-trash-full");
+    setIcon(isTrashEmpty ? QStringLiteral("user-trash") : QStringLiteral("user-trash-full"));
 }
 
 void PlacesItem::updateBookmarkForRole(const QByteArray& role)
@@ -317,11 +317,11 @@ void PlacesItem::updateBookmarkForRole(const QByteArray& role)
     } else if (role == "url") {
         m_bookmark.setUrl(url());
     } else if (role == "udi)") {
-        m_bookmark.setMetaDataItem("UDI", udi());
+        m_bookmark.setMetaDataItem(QStringLiteral("UDI"), udi());
     } else if (role == "isSystemItem") {
-        m_bookmark.setMetaDataItem("isSystemItem", isSystemItem() ? "true" : "false");
+        m_bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), isSystemItem() ? QStringLiteral("true") : QStringLiteral("false"));
     } else if (role == "isHidden") {
-        m_bookmark.setMetaDataItem("IsHidden", isHidden() ? "true" : "false");
+        m_bookmark.setMetaDataItem(QStringLiteral("IsHidden"), isHidden() ? QStringLiteral("true") : QStringLiteral("false"));
     }
 }
 
@@ -332,6 +332,6 @@ QString PlacesItem::generateNewId()
     // " (V2)" to indicate that the ID has been generated by
     // a new version of the places view.
     static int count = 0;
-    return QString::number(QDateTime::currentDateTime().toTime_t()) +
+    return QString::number(QDateTime::currentDateTimeUtc().toTime_t()) +
             '/' + QString::number(count++) + " (V2)";
 }
